@@ -1,17 +1,16 @@
+use 5.006;    # our
 use strict;
 use warnings;
 
 package App::colourhexdump;
-BEGIN {
-  $App::colourhexdump::AUTHORITY = 'cpan:KENTNL';
-}
-{
-  $App::colourhexdump::VERSION = '0.01011318';
-}
+
+our $VERSION = '1.000000';
 
 # ABSTRACT: HexDump, but with character-class highlighting.
 
-use Moose;
+our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
+
+use Moose qw( has with );
 use MooseX::Getopt::Dashes 0.37;
 with qw( MooseX::Getopt::Dashes );
 
@@ -21,6 +20,31 @@ use App::colourhexdump::Formatter;
 use namespace::autoclean;
 
 
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 has colour_profile => (
   metaclass     => 'Getopt',
   isa           => 'Str',
@@ -86,6 +110,13 @@ has 'colour' => (
 );
 
 
+
+
+
+
+
+
+
 sub BUILD {
   my $self = shift;
   push @{ $self->_files() }, @{ $self->extra_argv };
@@ -95,9 +126,15 @@ sub BUILD {
 
 
 
+
+
+
+
+
+
 sub get_filehandle {
-  my ( $self, $filename ) = @_;
-  if ( $filename eq q[-] ) {
+  my ( undef, $filename ) = @_;
+  if ( q[-] eq $filename ) {
     return \*STDIN;
   }
   require Carp;
@@ -106,6 +143,13 @@ sub get_filehandle {
 }
 
 
+
+
+
+
+
+
+
 sub run {
   my $self = shift;
   if ( not @{ $self->_files } ) {
@@ -138,7 +182,7 @@ sub run {
       $self->get_filehandle($_),
       sub {
         print $prefix . shift;
-      }
+      },
     );
   }
   return 1;
@@ -152,13 +196,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 App::colourhexdump - HexDump, but with character-class highlighting.
 
 =head1 VERSION
 
-version 0.01011318
+version 1.000000
 
 =head1 SYNOPSIS
 
@@ -208,7 +254,7 @@ Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Kent Fredric <kentnl@cpan.org>.
+This software is copyright (c) 2014 by Kent Fredric <kentnl@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
